@@ -1,5 +1,7 @@
 from dynaconf import FlaskDynaconf
-from flask import Flask
+from wtforms.validators import ValidationError
+from flask import Flask,request,render_template
+
 import flask_bootstrap 
 from flask_babelex import Babel
 from hiddifypanel.panel.database import db
@@ -32,18 +34,28 @@ def create_app(**config):
     # "hiddifypanel.panel.restapi:init_app",]
     # )  # Load extensions from settings.toml
     app.config.update(config)  # Override with passed config
-
+    app.config['WTF_CSRF_CHECK_DEFAULT']=False
+    
+    
     babel = Babel(app)
     @babel.localeselector
     def get_locale():
         # Put your logic here. Application can store locale in
         # user profile, cookie, session, etc.
         from hiddifypanel.models import ConfigEnum,hconfig
+        if "admin" in request.base_url:
+            return hconfig(ConfigEnum.admin_lang) or hconfig(ConfigEnum.lang) or 'fa'
         return hconfig(ConfigEnum.lang) or "fa"
 
     from flask_wtf.csrf import CSRFProtect
 
     csrf = CSRFProtect(app)
+    @app.before_request
+    def check_csrf():
+        if  "/admin/user/" in request.base_url :return
+        if  "/admin/domain/" in request.base_url :return
+        if "/admin/actions/" in request.base_url :return
+        csrf.protect()
     # app=ProxyFix(app, x_for=1, x_host=1,x_proto=1,x_port=1,x_prefix=1)
     app.jinja_env.globals['get_locale'] = get_locale
     
