@@ -10,7 +10,8 @@ from flask_admin.base import expose
 
 
 import re
-from flask import render_template,current_app,flash, Markup,url_for
+from flask import render_template,current_app, Markup,url_for
+from hiddifypanel.panel.hiddify import flash
 from hiddifypanel.models import  User,Domain,DomainType,StrConfig,ConfigEnum,get_hconfigs
 from hiddifypanel.panel.database import db
 from wtforms.fields import *
@@ -38,6 +39,7 @@ class SettingAdmin(FlaskView):
             
             boolconfigs=BoolConfig.query.all()
             bool_types={c.key:'bool' for c in boolconfigs}
+            old_config=get_hconfigs()
             for cat,vs in form.data.items():#[c for c in ConfigEnum]:
             
                 if type(vs) is dict:
@@ -45,14 +47,18 @@ class SettingAdmin(FlaskView):
             
                         if k in [c for c in ConfigEnum]:
                             if k in bool_types:
-                                BoolConfig.query.filter(BoolConfig.key==k).first().value=v
+                                BoolConfig.query.filter(BoolConfig.key==k).first().value=v                            
                             else:
+                                if "_domain" in k:
+                                    v=v.lower()
                                 StrConfig.query.filter(StrConfig.key==k).first().value=v
                     
                 # print(cat,vs)
             db.session.commit()
             from flask_babel import refresh; refresh()
-            hiddify.flash_config_success()
+            
+            do_full_install=old_config[ConfigEnum.telegram_lib]!=hconfig(ConfigEnum.telegram_lib)
+            hiddify.flash_config_success(full_install=do_full_install)
             
 
             return render_template('config.html', form=form)
@@ -107,13 +113,24 @@ def get_config_form():
         if cat=='hidden':continue
 
         cat_configs=[c for c in configs if c.key.category()==cat]
+        if len(cat_configs)==0:continue
+        
         class CategoryForm(FlaskForm):
             description_for_fieldset=wtf.fields.TextAreaField("",description=_(f'config.{cat}.description'),render_kw={"class":"d-none"})
         for c in cat_configs:
             if c.key in bool_types:
                 field= SwitchField(_(f'config.{c.key}.label'), default=c.value,description=_(f'config.{c.key}.description')) 
-            elif c.key==ConfigEnum.lang:
-                field=wtf.fields.SelectField(_("config.lang.label"),choices=[("en",_("lang.en")),("fa",_("lang.fa")),("zh",_("lang.zh"))],description=_("config.lang.description"),default=hconfig(ConfigEnum.lang))
+            elif c.key==ConfigEnum.lang or c.key==ConfigEnum.admin_lang:
+                field=wtf.fields.SelectField(_(f"config.{c.key}.label"),choices=[("en",_("lang.en")),("fa",_("lang.fa")),("zh",_("lang.zh"))],description=_(f"config.{c.key}.description"),default=hconfig(c.key))
+            elif c.key==ConfigEnum.telegram_lib:
+                # if hconfig(ConfigEnum.telegram_lib)=='python':
+                #     continue6
+                libs=[("python",_("lib.telegram.python")),("tgo",_("lib.telegram.go")),("orig",_("lib.telegram.orignal")),("erlang",_("lib.telegram.erlang"))]
+                field=wtf.fields.SelectField(_("config.telegram_lib.label"),choices=libs,description=_("config.telegram_lib.description"),default=hconfig(ConfigEnum.telegram_lib))
+            elif c.key==ConfigEnum.branding_freetext:
+                validators=[wtf.validators.Length(max=2048)]
+                render_kw={'class':"ltr",'maxlength':2048}
+                field= wtf.fields.TextAreaField(_(f'config.{c.key}.label'), validators, default=c.value, description=_(f'config.{c.key}.description'),render_kw=render_kw) 
             else:
                 render_kw={'class':"ltr"}
                 validators=[]
@@ -122,13 +139,14 @@ def get_config_form():
                 elif 'domain' in c.key:
                     validators.append(wtf.validators.Regexp("^([A-Za-z0-9\-\.]+\.[a-zA-Z]{2,})$",re.IGNORECASE,_("config.Invalid domain")))
                     if c.key!=ConfigEnum.decoy_domain:
-                        validators.append(wtf.validators.NoneOf(db.session.query(Domain.domain).all(),_("config.Domain already used")))
+                        validators.append(wtf.validators.NoneOf([d.domain.lower() for d in Domain.query.all()],_("config.Domain already used")))
+                        validators.append(wtf.validators.NoneOf([cc.value.lower() for cc in StrConfig.query.all() if cc.key!=c.key and  "fakedomain" in cc.key and cc.key!=ConfigEnum.decoy_domain],_("config.Domain already used")))
                     render_kw['required']=""
-        
+                
 
-                # if c.key==ConfigEnum.decoy_domain:
-                #     validators.append(wtf.validators.Regexp("http(s|)://([A-Za-z0-9\-\.]+\.[a-zA-Z]{2,})/?",re.IGNORECASE,_("config.Invalid decoy_domain")))
-                #     render_kw['required']=""
+                if c.key==ConfigEnum.branding_site:
+                    validators.append(wtf.validators.Regexp("()|(http(s|)://([A-Za-z0-9\-\.]+\.[a-zA-Z]{2,})/?.*)",re.IGNORECASE,_("config.Invalid brand link")))
+                    # render_kw['required']=""
 
                 if 'secret' in c.key:
                     validators.append(wtf.validators.Regexp("^[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}$",re.IGNORECASE,_('config.invalid uuid')))
